@@ -4,7 +4,7 @@ try:
 except ImportError:
   pass
 
-def haproxyctl(conf):
+def haproxyctl(socket_path):
   while True:
     try:
       l = raw_input('> ')
@@ -14,7 +14,7 @@ def haproxyctl(conf):
     if l == 'quit':
       break
     s = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
-    s.connect(conf['socket_path'])
+    s.connect(socket_path)
     s.send('%s\n' % l)
     while True:
       r = s.recv(1024)
